bayespy.nodes.CategoricalMarkovChain.initialize_from_value
==========================================================

.. currentmodule:: bayespy.nodes

.. automethod:: CategoricalMarkovChain.initialize_from_value